@@ -1,7 +1,7 @@
-#$Id: Obj.pm 23324 2006-07-21 13:35:50Z wsnyder $
+#$Id: Obj.pm 31185 2007-02-01 14:40:37Z wsnyder $
 ######################################################################
 #
-# This program is Copyright 2002-2006 by Wilson Snyder.
+# This program is Copyright 2002-2007 by Wilson Snyder.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of either the GNU General Public License or the
@@ -32,7 +32,7 @@ use vars qw(@ISA $Debug);
 @ISA=qw(Make::Cache);
 *Debug = \$Make::Cache::Debug;  	# "Import" $Debug
 
-our $VERSION = '1.041';
+our $VERSION = '1.042';
 
 our $Cc_Running_Lock;
 our $Temp_Filename;
@@ -349,8 +349,8 @@ sub runtime_write {
     # Update the runtime database
     return if !$self->{runtime};
     Make::Cache::Runtime::write(key=>$self->runtime_key_digest,
-			 persist=>{ key=>$self->runtime_key_digest,
-				    #prog=>'objcache',  #smaller-> more likely to fit in directories
+			 persist=>{ #key=>$self->runtime_key_digest,	#smaller-> more likely to fit in directories
+				    #prog=>'objcache',			#smaller-> more likely to fit in directories
 				    runtime=>$self->{runtime}, },
 			 );
 }
@@ -532,7 +532,7 @@ compile.
 
 The latest version is available from CPAN and from L<http://www.veripool.com/>.
 
-Copyright 2000-2006 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2007 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License or the Perl Artistic License.
 
